#!/usr/bin/env bash

set -e

add_apt_key() {
    retries=20
    retry=1
    while ! curl -fsSL "${K8S_EXTRA_REPO_URL}/${K8S_EXTRA_REPO_KEY}" | apt-key add -
    do
        if [[ $retry -le $retries ]]; then
            echo "apt-key add command has failed. Retrying ${retry}/${retries}"
            retry=$((retry+1))
            sleep 5
        else
            echo "The command has failed after ${retries} attempts" && exit 1
        fi
    done
}

apt_get_update() {
    retries=20
    retry=1
    while apt-get ${APT_OPTS} update | tee /dev/stderr | grep -E "^Err:"
    do
        if [[ $retry -le $retries ]]; then
            echo "apt-get update command has failed. Retrying ${retry}/${retries}"
            retry=$((retry+1))
            sleep 5
        else
            echo "The command has failed after ${retries} attempts" && exit 1
        fi
    done
}
