#!/usr/bin/env bash

set -e

source vars.sh
source common.sh

if [ -e /etc/system-release ]; then
    OS_FAMILY="rhel"
else
    OS_FAMILY="debian"
fi

: "${ITEM_PARAM_MCP_APT_MIRROR:="https://mirror.mirantis.com"}"

if [ "$OS_FAMILY" == "debian" ]; then
    : "${ITEM_PARAM_KAAS_UBUNTU_REPO:=${KAAS_UBUNTU_REPO}}"

    UBUNTU_CODENAME='unknown'
    source <(cat /etc/os-release | grep UBUNTU_CODENAME)
    if [ "${UBUNTU_CODENAME}" == "unknown" ] && which lsb_release >/dev/null; then
        UBUNTU_CODENAME=$(lsb_release --codename --short)
    fi

    if [ "${UBUNTU_CODENAME}" != "bionic" ] && [ "${UBUNTU_CODENAME}" != "focal" ]; then
      echo "Unsupported ubuntu release codename: '${UBUNTU_CODENAME}'"
      exit 1
    fi

    K8S_EXTRA_REPO_VERSION='0.0.9'
    K8S_EXTRA_REPO_KEY="archive-kubernetes-extra-${K8S_EXTRA_REPO_VERSION}.key"
    K8S_EXTRA_REPO_URL="${ITEM_PARAM_MCP_APT_MIRROR}/kaas/kubernetes-extra-${K8S_EXTRA_REPO_VERSION}/${UBUNTU_CODENAME}"

    export DEBIAN_FRONTEND=noninteractive
    export DEBCONF_NONINTERACTIVE_SEEN=true
    export APT_OPTS="-o APT::Install-Suggests=0 -o APT::Install-Recommends=0 -o Dpkg::Options::=--force-confold -o Dpkg::Options::=--force-confdef"
    if [ "${ITEM_PARAM_PROXY_ENABLED}" == "true" ]; then
        export APT_OPTS="${APT_OPTS} -o Acquire::https::CAInfo=${CERT_FILE}"
    fi
    # Install ca-certificates to access Mirantis mirror
    apt_get_update
    dpkg -s ca-certificates &> /dev/null || apt-get install -y ${APT_OPTS} ca-certificates

    # Remove default repositories
    find /etc/apt/ -name *.list -delete

    # Add Ubuntu mirrors
    cat <<EOF > /etc/apt/sources.list
# Ubuntu snapshot
deb [arch=amd64] ${ITEM_PARAM_MCP_APT_MIRROR}/${ITEM_PARAM_KAAS_UBUNTU_REPO} ${UBUNTU_CODENAME} main restricted universe
deb [arch=amd64] ${ITEM_PARAM_MCP_APT_MIRROR}/${ITEM_PARAM_KAAS_UBUNTU_REPO} ${UBUNTU_CODENAME}-updates main restricted universe
deb [arch=amd64] ${ITEM_PARAM_MCP_APT_MIRROR}/${ITEM_PARAM_KAAS_UBUNTU_REPO} ${UBUNTU_CODENAME}-security main restricted universe
EOF

    # Prefer Mirantis owned packages over Ubuntu packages
    cat <<EOF > /etc/apt/preferences.d/mirantis
Package: *
Pin: release o=Mirantis
Pin-Priority: 1001
EOF

    # Install package prerequisites
    apt_get_update
    apt-get install -y ${APT_OPTS} curl gnupg-agent

    update-alternatives --install /usr/bin/python python /usr/bin/python3 1

    # Add kubernetes-extra repo and install Ansible
    cat <<EOF >> /etc/apt/sources.list
    # kubernetes-extra repo
deb ${K8S_EXTRA_REPO_URL} ${UBUNTU_CODENAME} main
EOF

    add_apt_key
    apt_get_update
    apt-get install -y ${APT_OPTS} ansible

else
    source <(cat /etc/os-release | grep VERSION_ID)
    VERSION_ID="${VERSION_ID%%.*}"
    source <(cat /etc/os-release | grep -E "^ID=")
    PROXY="${HTTPS_PROXY:-${HTTP_PROXY}}"
    if [ "${ID}" == "centos" ] && [ -n "${PROXY}" ]; then
          sed -i '/#\?proxy \?=.*/d' /etc/yum.conf
          sed -i "/^\[main\]/a proxy=${PROXY}" /etc/yum.conf
    fi
    cat <<EOF > /etc/yum.repos.d/kubernetes_extra.repo
[kubernetes_extra]
name=Kubernetes Extra
baseurl=${ITEM_PARAM_MCP_APT_MIRROR}/kaas/kubernetes-extra-rhel${VERSION_ID}-0.0.6/
gpgcheck=0
enabled=1
EOF
    if [ "${ITEM_PARAM_PROXY_ENABLED}" == "true" ]; then
        # Requests to MCC cache should not use MCC proxy
        echo 'proxy=_none_' >> /etc/yum.repos.d/kubernetes_extra.repo
    fi
    yum -y install yum-utils
    if [ "${ID}" == "rhel" ] && [ "${VERSION_ID}" == "7" ]; then
        yum-config-manager --enable \
        rhui-rhel-${VERSION_ID}-server-rhui-extras-rpms \
        rhel-${VERSION_ID}-server-extras-rpms
    fi
    yum -y install ca-certificates curl ansible
fi

ansible-playbook --version
